@@ -267,7 +267,8 @@ class SystemTrayIcon(QSystemTrayIcon):
         self.system_bus = system_bus
         self.service = service
 
-        me = "__init__"
+        #me = "__init__"
+        me = "updater-systray"
         self.version_monitor = VersionMonitor('mx-updater')
 
         self.running_version = self.version_monitor.running_version
@@ -283,6 +284,8 @@ class SystemTrayIcon(QSystemTrayIcon):
         self.is_detect_fluxbox = self.detect_fluxbox()
         self.disable_hide_until = (self.is_detect_fluxbox, self.is_detect_plasma)
 
+        self.is_icon_set = False
+
         # on startup, try to acquire a lock
         self.run_time_path = acquire_runtime_lock()
         if self.run_time_path is None:
@@ -347,10 +350,10 @@ class SystemTrayIcon(QSystemTrayIcon):
 
 
         # try update state with retrieved available upgrades via D-Bus
-        logger.info("[%s] get_upgrades_available", me)
+        logger.debug("[%s] get_upgrades_available", me)
         upgrades = self.get_upgrades_available()
         logger.debug("D-Bus GetUpgradesAvailable: %s", upgrades)
-        logger.info("[%s]D-Bus GetUpgradesAvailable: %s",me, upgrades)
+        logger.debug("[%s]D-Bus GetUpgradesAvailable: %s",me, upgrades)
 
 
         #---------------------------------------------------------------
@@ -382,7 +385,7 @@ class SystemTrayIcon(QSystemTrayIcon):
 
         # request refresh
         # self.request_refresh()
-        logger.info("[%s] self.request_refresh()", me)
+        logger.debug("[%s] self.request_refresh()", me)
         self.request_refresh()
 
         # Connect the PyQt signal to the update_tray_icon method
@@ -457,12 +460,12 @@ class SystemTrayIcon(QSystemTrayIcon):
         #self.set_icon_look()
         #hide_until_upgrades_available = self._settings.get("hide_until_upgrades_available", False)
         #self.setVisible(not hide_until_upgrades_available)
-        logger.info("[%s] Init UI self.initUI()", me)
+        logger.debug("[%s] Init UI self.initUI()", me)
         self.initUI()
-        logger.info("[%s] self.set_icon_look()", me)
+        logger.debug("[%s] self.set_icon_look()", me)
         self.set_icon_look()
 
-        logger.info("[%s] set_tooltip() with _state:\n%s", me, self._state)
+        logger.debug("[%s] set_tooltip() with _state:\n%s", me, self._state)
         self.set_tooltip()
 
         #hide_until_upgrades_available = self._settings.get('hide_until_upgrades_available', False)
@@ -683,7 +686,7 @@ class SystemTrayIcon(QSystemTrayIcon):
 
         #--- upgrade_type --------------------------------------------
         upgrade_type_default = self.defaults.get('Settings',{}).get("upgrade_type_default")
-        print(f"load_settings upgrade_type = {upgrade_type_default}")
+        #print(f"load_settings upgrade_type = {upgrade_type_default}")
         upgrade_type = self.qsettings.value("Settings/upgrade_type", upgrade_type_default)
         if upgrade_type not in self.defaults.get('Settings',{}).get("upgrade_type_allowed"):
             upgrade_type = "full-upgrade"
@@ -693,10 +696,10 @@ class SystemTrayIcon(QSystemTrayIcon):
         #--------------------------------------------------------------
         #--- use_nala -------------------------------------------------
         use_nala_default = self.defaults.get('Settings',{}).get("use_nala_default")
-        print(f"load_settings use_nala_default = {use_nala_default}")
+        #print(f"load_settings use_nala_default = {use_nala_default}")
         try:
             use_nala = self.qsettings.value("Settings/use_nala", use_nala_default, type=bool)
-            print(f"loaded Qsettings use_nala = {use_nala}")
+            #print(f"loaded Qsettings use_nala = {use_nala}")
         except:
             use_nala = False
         self.selected_settings["use_nala"] = use_nala
@@ -1012,7 +1015,7 @@ class SystemTrayIcon(QSystemTrayIcon):
         me = "on_basic_upgrades_changed"
         logger.debug("[%s] D-Bus upgrades_changed_signal received with value: %r", me, basic_upgrades_available)
         upgrade_type = self._settings.get("upgrade_type", "full-upgrade")
-        print(f"upgrade_type is '{upgrade_type}' type={type(upgrade_type)}")
+        #print(f"upgrade_type is '{upgrade_type}' type={type(upgrade_type)}")
         #if upgrade_type not in  ['basic-upgrade', 'upgrade']:
         #    print(f"upgrade_type='{upgrade_type}' type={type(upgrade_type)}")
         #    logger.debug("[%s] Signal ignored - current upgrade-type is '%s'", me, upgrade_type)
@@ -1114,7 +1117,7 @@ class SystemTrayIcon(QSystemTrayIcon):
             else:
                 self._state["upgrades-available"][upgrade_type] = upgrades_available
 
-        logger.info("[%s] set_icon_look()", me)
+        logger.debug("[%s] set_icon_look()", me)
         self.set_icon_look()
         logger.debug("[%s] set_tooltip() with _state:\n%s", me, self._state)
         self.set_tooltip()
@@ -1124,7 +1127,7 @@ class SystemTrayIcon(QSystemTrayIcon):
     def update_tray_icon(self, key, value):
         me = "update_tray_icon"
         # update tray icon based key,value pair
-        logger.info("[%s] Try to update system tray icon with key=value: %s=%s", me, key, value)
+        logger.debug("[%s] Try to update system tray icon with key=value: %s=%s", me, key, value)
         match key:
             case 'upgrade_type':
                 upgrade_type = 'full-upgrade' if value == 'full-upgrade' else 'basic-upgrade'
@@ -1135,20 +1138,20 @@ class SystemTrayIcon(QSystemTrayIcon):
             case 'icon_look':
                 icon_look = value
                 if value.startswith("wireframe"):
-                    logger.info("[%s] transparent value %s", me, value)
+                    logger.debug("[%s] transparent value %s", me, value)
                     icon_look, _, transparent = value.partition(':')
 
-                    logger.info("[%s] icon_look transparent  %s %s", me, icon_look, transparent)
+                    logger.debug("[%s] icon_look transparent  %s %s", me, icon_look, transparent)
                     transparent = transparent == "transparent"
-                    logger.info("[%s] itransparent  %s ", me, transparent)
+                    logger.debug("[%s] itransparent  %s ", me, transparent)
                     self._settings['wireframe_transparent'] = transparent == "transparent"
                     self.qsettings.sync()
                     qtransparent = self.qsettings.value('Settings/wireframe_transparent')
-                    logger.info("[%s] qtransparent  %s ", me, qtransparent)
+                    logger.debug("[%s] qtransparent  %s ", me, qtransparent)
 
                 self._settings['icon_look'] = icon_look
                 # TODO: needs update_apt_icon
-                logger.info("[%s] set_icon_look()", me)
+                logger.debug("[%s] set_icon_look()", me)
                 self.set_icon_look()
 
             case 'left_click':
@@ -1166,14 +1169,14 @@ class SystemTrayIcon(QSystemTrayIcon):
                     hide_until_upgrades_available = value.lower() in ("true", "yes", "1")
 
                 self._settings['hide_until_upgrades_available'] = value.lower() in ("true", "yes", "1")
-                logger.info("[%s] set_tooltip()", me)
+                logger.debug("[%s] set_tooltip()", me)
                 self.set_tooltip()
                 #self._apply_tray_visibility(not hide_until_upgrades_available)
                 pass
 
             case 'auto_upgrade':
                 is_unattended_upgrade_enabled = self.is_unattended_upgrade_enabled()
-                logger.info("[%s] auto_upgrade is currently enabled: %r ", me, is_unattended_upgrade_enabled)
+                logger.debug("[%s] auto_upgrade is currently enabled: %r ", me, is_unattended_upgrade_enabled)
                 self.enable_auto_upgrade_log()
                 self.set_tooltip()
                 pass
@@ -1298,22 +1301,40 @@ class SystemTrayIcon(QSystemTrayIcon):
                 do_notify = False
                 do_hide = True
                 #self._clean_notifications()
-                if self._icon_none:
-                    set_icon = self._icon_none
+                if self._total_updates:
+                    do_hide = False
+                    if self._icon_some:
+                        set_icon = self._icon_some
+                else:
+                    do_hide = True
+                    if self._icon_none:
+                        set_icon = self._icon_none
 
             if is_full:
                 if full_upgrades_available == basic_upgrades_available:
                     do_notify = False
                     do_hide = True
                     #self._clean_notifications()
-                    if self._icon_none:
-                        set_icon = self._icon_none
+                    if self._total_updates:
+                        do_hide = False
+                        if self._icon_some:
+                            set_icon = self._icon_some
+                    else:
+                        do_hide = True
+                        if self._icon_none:
+                            set_icon = self._icon_none
                 else:
                     do_notify = True
                     do_hide = False
                     #self._clean_notifications()
-                    if self._icon_some:
-                        set_icon = self._icon_some
+                    if self._total_updates:
+                        do_hide = False
+                        if self._icon_some:
+                            set_icon = self._icon_some
+                    else:
+                        do_hide = True
+                        if self._icon_none:
+                            set_icon = self._icon_none
 
 
         tooltip= f"{tooltip_upgrade_type}\n{tooltip_available}"
@@ -1324,6 +1345,7 @@ class SystemTrayIcon(QSystemTrayIcon):
         if set_icon:
             logger.debug("[%s] setIcon(QIcon('%s')", me, set_icon)
             self.setIcon(QIcon(set_icon))
+            self.is_icon_set = True
 
         value = self.qsettings.value('Settings/hide_until_upgrades_available', False)
         logger.debug("[%s] self.qsettings.value('Settings/hide_until_upgrades_available', False) is %s", me, value)
@@ -1336,7 +1358,9 @@ class SystemTrayIcon(QSystemTrayIcon):
         logger.debug("[%s] hide_until_upgrades_available is : %r", me, hide_until_upgrades_available)
         logger.debug("[%s] hide_tray_icon is : %r", me, hide_until_upgrades_available)
         logger.debug("[%s] self._apply_tray_visibility(%r)", me, not hide_tray_icon)
-        self._apply_tray_visibility(not hide_tray_icon)
+        if self.is_icon_set:
+            self._apply_tray_visibility(not hide_tray_icon)
+
         logger.debug("[%s] ----------------------------------------------", me)
 
 
@@ -1382,11 +1406,11 @@ class SystemTrayIcon(QSystemTrayIcon):
         icon_some = icons.get("icon_some")
         icon_none = icons.get("icon_none")
         wireframe_transparent = self.qsettings.value('Settings/wireframe_transparent')
-        logger.info("[%s] self.qsettings.value('Settings/wireframe_transparent') : %s [%s]", me, wireframe_transparent, type(wireframe_transparent))
+        logger.debug("[%s] self.qsettings.value('Settings/wireframe_transparent') : %s [%s]", me, wireframe_transparent, type(wireframe_transparent))
         #wireframe_transparent = self._settings.get('wireframe_transparent', "true")
-        #logger.info("[%s] self._settings.get('wireframe_transparent') : %s [%s]", me, wireframe_transparent, type(wireframe_transparent))
+        #logger.debug("[%s] self._settings.get('wireframe_transparent') : %s [%s]", me, wireframe_transparent, type(wireframe_transparent))
         wireframe_transparent = str(wireframe_transparent).lower() in ['true', 'on', '1']
-        logger.info("[%s] self.qsettings.value('Settings/wireframe_transparent') : %s [%s]", me, wireframe_transparent, type(wireframe_transparent))
+        logger.debug("[%s] self.qsettings.value('Settings/wireframe_transparent') : %s [%s]", me, wireframe_transparent, type(wireframe_transparent))
 
         if icon_look.startswith('wireframe') and wireframe_transparent:
             icon_none = icons.get('icon_none_transparent', icon_none)
@@ -1401,28 +1425,31 @@ class SystemTrayIcon(QSystemTrayIcon):
         total_updates = upgraded + newly_installed
 
 
-
         set_icon = None
-        if total_updates and not is_unattended_upgrade_enabled:
+        # always show "some"-icons if we have updates, even if auto-upgrade is enabled
+        # if total_updates and not is_unattended_upgrade_enabled:
+        if total_updates:
             set_icon = self._icon_some
-            self.setVisible(True)
+            if self.is_icon_set:
+                self.setVisible(True)
         else:
             set_icon = self._icon_none
 
-        if (is_unattended_upgrade_enabled and total_updates == 0
-            and full_upgrades_available == basic_upgrades_available
-            ):
-            set_icon = self._icon_none
+        #if (is_unattended_upgrade_enabled and total_updates == 0
+        #    and full_upgrades_available == basic_upgrades_available
+        #    ):
+        #    set_icon = self._icon_none
 
         if set_icon:
             logger.debug("[%s] setIcon(QIcon('%s')", me, set_icon)
             self.setIcon(QIcon(set_icon))
-
+            self.is_icon_set = True
 
         if total_updates:
             self._apply_entry_visible("view_and_upgrade", True)
             self._apply_entry_visible("hide_until_updates_available", False)
-            self._apply_tray_visibility(True)
+            if self.is_icon_set:
+                self._apply_tray_visibility(True)
         else:
             self._apply_entry_visible("view_and_upgrade", False)
 
@@ -1480,7 +1507,8 @@ class SystemTrayIcon(QSystemTrayIcon):
             ("auto_update_dpkg_log", _("Auto-update dpkg log(s)"), True,  "/usr/libexec/mx-updater/mx-updater-auto-update_dpkg_log.py"),
             ("settings_editor",      _("Preferences"),             True,  "/usr/bin/mx-updater-settings"),
             ("updater_about",        _("About"),                   True,  "/usr/libexec/mx-updater/updater_about.py"),
-            ("updater_restart",      _("Restart"),                 True,  "/usr/libexec/mx-updater/updater-restart"),
+            #("updater_restart",      _("Restart"),                True,  "/usr/libexec/mx-updater/updater-restart"),
+            ("updater_restart",      _("Restart MX Updater"),      True,  "/usr/libexec/mx-updater/updater-restart"),
 
         ]
 
@@ -1767,7 +1795,7 @@ class SystemTrayIcon(QSystemTrayIcon):
                 logger.debug("loaded state file=%s\n%s", STATE_FILE, json.dumps(state, indent=2))
                 return state
         except (FileNotFoundError, json.JSONDecodeError) as e:
-            logger.info("state file not available %s ", STATE_FILE)
+            logger.debug("state file not available %s ", STATE_FILE)
             return None
 
     def validate_state(self, state: Dict[str, Any]) -> bool:
@@ -1776,7 +1804,7 @@ class SystemTrayIcon(QSystemTrayIcon):
             full_upgrades = state["upgrades-available"]["full-upgrade"]
             basic_upgrades = state["upgrades-available"]["basic-upgrade"]
         except (KeyError, TypeError) as e:
-            logger.info("state file missing required keys or wrong structure: %s")
+            logger.debug("state file missing required keys or wrong structure: %s")
             return False
 
         if not self.is_valid_upgrades_tuple(full_upgrades):
@@ -1883,24 +1911,24 @@ class SystemTrayIcon(QSystemTrayIcon):
         Make auto upgrade menu entries visible
         """
         me = "enable_auto_upgrade_log"
-        logger.info("[%s] check and enable auto_upgrade_log right click entries.", me)
+        logger.debug("[%s] check and enable auto_upgrade_log right click entries.", me)
 
         # check log view menu entry exists:
         if not (self.actions.get("auto_update_log") or self.actions.get("auto_update_dpkg_log")):
-            logger.info("[%s] no auto_upgrade_log  entries exists.", me)
+            logger.debug("[%s] no auto_upgrade_log  entries exists.", me)
             return
 
-        logger.info("[%s] set visibility for unattended-upgrades log.", me)
+        logger.debug("[%s] set visibility for unattended-upgrades log.", me)
         auto_upgrades_logs_available = self.auto_upgrades_logs_available()
-        logger.info("[%s] auto_upgrades_logs_available: %r , [%s]", me, auto_upgrades_logs_available, type(auto_upgrades_logs_available))
+        logger.debug("[%s] auto_upgrades_logs_available: %r , [%s]", me, auto_upgrades_logs_available, type(auto_upgrades_logs_available))
         # check and set visibility for unattended-upgrades log
         enable_auto_update_logs = (self.is_unattended_upgrade_enabled()
                                 or self.auto_upgrades_logs_available())
 
-        logger.info("[%s] set visibility for auto_update_log: %r", me, enable_auto_update_logs)
+        logger.debug("[%s] set visibility for auto_update_log: %r", me, enable_auto_update_logs)
         self.set_action_visble("auto_update_log", enable_auto_update_logs)
 
-        logger.info("[%s] set visibility for auto_update_dpkg_log: %r", me, enable_auto_update_logs)
+        logger.debug("[%s] set visibility for auto_update_dpkg_log: %r", me, enable_auto_update_logs)
         self.set_action_visble("auto_update_dpkg_log", enable_auto_update_logs)
 
 
@@ -2125,8 +2153,8 @@ def unhide_systray(bus):
     """
     key = "hide_until_upgrades_available"
     val = "false"
-    print("[Debug] Try to unhide Updater SystrayIcon")
-    logger.info("Try to unhide Updater SystrayIcon")
+    #print("[Debug] Try to unhide Updater SystrayIcon")
+    logger.debug("Try to unhide Updater SystrayIcon")
 
     try:
         qsettings = QSettings("MX-Linux", "mx-updater")
